Fix warnings in documentation generation
[linpy.git] / setup.py
index f72af50..05ea91c 100755 (executable)
--- a/setup.py
+++ b/setup.py
@@ -2,31 +2,31 @@
 
 # Copyright 2014 MINES ParisTech
 #
# This file is part of Linpy.
 #
# Linpy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
# Linpy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Linpy.  If not, see <http://www.gnu.org/licenses/>.
+# along with LinPy.  If not, see <http://www.gnu.org/licenses/>.
 
 from distutils.core import setup, Extension
 
 setup(
-    name='pypol',
+    name='LinPy',
     description='A polyhedral library based on ISL',
     author='MINES ParisTech',
-    packages=['pypol'],
+    packages=['linpy'],
     ext_modules = [
-        Extension('pypol._islhelper',
-            sources=['pypol/_islhelper.c'],
+        Extension('linpy._islhelper',
+            sources=['linpy/_islhelper.c'],
             libraries=['isl'])
     ]
 )
@@ -2,31 +2,31 @@
 # Copyright 2014 MINES ParisTech
 #
-# This file is part of Linpy.
+# This file is part of LinPy.
 #
@@ -2,31 +2,31 @@
 #
-# Linpy is free software: you can redistribute it and/or modify
+# LinPy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -2,31 +2,31 @@
 # (at your option) any later version.
 #
-# Linpy is distributed in the hope that it will be useful,
+# LinPy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the